@@ -20,11 +20,11 @@ Lingua::RO::Numbers - Converts numeric values into their Romanian string equival
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 # Numbers => text
 our %DIGITS;
@@ -47,8 +47,8 @@ our %WORDS;
 @WORDS{qw(o un doua cin sai ob)} = (1, 1, 2, 5, 6, 8);
 
 # Colocvial
-@WORDS{qw(unspe doispe treispe paispe cinspe cinsprezece saispe saptespe optspe nouaspe)} =
-  (11, 12, 13, 14, 15, 15, 16, 17, 18, 19);
+@WORDS{qw(unspe doispe treispe paispe cinspe cinsprezece saispe saptespe saptuspe optspe nouaspe)} =
+  (11, 12, 13, 14, 15, 15, 16, 17, 17, 18, 19);
 
 # This array contains number greater than 1000 and it's used to convert numbers into text
 our @BIGNUMS = (
@@ -62,6 +62,7 @@ our @BIGNUMS = (
                 {num => 10**21, sg => 'triliard',    pl => 'triliarde'},
                 {num => 10**24, sg => 'cvadrilion',  pl => 'cvadrilioane'},
                 {num => 10**27, sg => 'cvadriliard', pl => 'cvadriliarde'},
+                {num => 'inf',  sg => 'inifinit',    pl => 'infinit'},
                );
 
 # This hash is a reversed version of the above array and it's used to convert text into numbers
@@ -465,7 +466,7 @@ sub _number_to_ro {
         foreach my $i (0 .. $#BIGNUMS - 1) {
             my $j = $#BIGNUMS - $i;
 
-            if ($number >= $BIGNUMS[$j - 1]{num} && $number < $BIGNUMS[$j]{num}) {
+            if ($number >= $BIGNUMS[$j - 1]{num} && $number <= $BIGNUMS[$j]{num}) {
                 my $cat = int $number / $BIGNUMS[$j - 1]{num};
                 $number -= $BIGNUMS[$j - 1]{num} * int($number / $BIGNUMS[$j - 1]{num});
 
